pub(crate) fn dcparse_pipeline(
inputs: Vec<(String, String)>,
) -> Result<DCFile, DCReadError>Expand description
Runs the entire DC parser pipeline. The input is an array of strings that represent the input DC files in UTF-8, and the output is the final DC element tree data structure to be used by Donet.